Jmbo Listing
============
**A listing is a stored search that is rendered in a certain style.**

.. figure:: https://travis-ci.org/praekelt/jmbo-listing.svg?branch=develop
   :align: center
   :alt: Travis

.. contents:: Contents
    :depth: 5

Installation
------------

#. Install or add ``jmbo-listing`` to your Python path.

#. Add ``listing`` to your ``INSTALLED_APPS`` setting.

#. Run ``manage.py migrate listing``.

Usage
-----

Full documentation is at http://jmbo-listing.readthedocs.org.

